Renderer

Struct Renderer 

pub struct Renderer { /* private fields */ }

Implementations

Source

impl Renderer

pub fn new() -> RendererResult<Self>

Creates a new Renderer instance with no windows.

pub fn create_window( &mut self, title: impl ToString, width: u32, height: u32, ) -> WindowId

Creates a new window with the given title, dimensions, and resizability. Returns a WindowId that can be used to interact with the window. Initializes the GPU context if this is the first window created.

pub fn create_window_ext( &mut self, props: impl Into<AdvancedWindowProperties>, ) -> WindowId

Creates a new window with the given properties. Returns a WindowId that can be used to interact with the window. Initializes the GPU context if this is the first window created.

Use WindowProperties for normal cases and use AdvancedWindowProperties for advanced cases.

pub fn create_canvas( &mut self, width: u32, height: u32, ) -> RendererResult<Canvas>

Create a new canvas with the given width and height.

pub fn poll(&mut self) -> Vec<(WindowId, WindowEvent)>

Pumps the event loop and returns all window events since the last call. Resize, cursor movement, and focus events are also forwarded to their respective windows internally. Clears all queued WinitEvents.

Only available on Windows, macOS, Linux, and Android.

pub fn poll_raw(&mut self) -> Vec<(WindowId, WinitEvent)>

Pumps the event loop and returns all raw winit events since the last call. Resize, cursor movement, and focus events are also forwarded to their respective windows internally. Clears all queued WindowEvents.

Only available on Windows, macOS, Linux, and Android.

pub fn poll_full(&mut self) -> Vec<(WindowId, (WindowEvent, WinitEvent))>

Pumps the event loop and returns all window events and raw winit events since the last call. Resize, cursor movement, and focus events are also forwarded to their respective windows internally. Clears all queued WindowEvents.

Only available on Windows, macOS, Linux, and Android.

pub fn close_window(&mut self, id: WindowId) -> bool

Closes the window with the given WindowId, removing it from the renderer. Returns true if a window with that ID existed.

pub fn get_window<'a>(&'a mut self, id: WindowId) -> Option<WindowDraw<'a>>

Returns a WindowDraw for the given WindowId, if it exists.

pub fn flush(&mut self) -> RendererResult<()>

Submits all queued draw calls for each open window to the GPU and presents their frames.

pub fn is_running(&self) -> bool

Returns true if any windows are still open.